
#include <stdio.h>
#include <stdlib.h>
#include <time.h>

#define DEFAULT_SIZE      10                 // Default board size

// #define PRINT_SOLUTIONS

/////////////////////////s

void print_solution(int board[], int size)
{
#ifdef PRINT_SOLUTIONS

  for (int i=0; i<size; i++)
  {
    for (int j=0; j<size; j++)
    {
      if (j == board[i])
        printf("Q");
      else
        printf(".");
    }
    printf("\n");
  }

  printf("\n");

#endif
}

int place_queen(int column, int board[], int size)
{
  // Total solutions for this level
  int n_solutions = 0;

  // Try to place a queen in each line of <column>
  for (int i=0; i<size; i++)
  {
    // Place the queen
    board[column] = i;
    
    // Check if this board is still a solution
    bool is_sol = true;
    for (int j=column-1; j>=0; j--)
    {
      if ((board[column] == board[j])               ||
          (board[column] == board[j] - (column-j))  ||
          (board[column] == board[j] + (column-j)))
      {
        is_sol = false;
        break;
      }
    }
    if (is_sol)     // It is!
    {
      if (column == size-1)
      {
        // If we are at the last level, increment
        // the number of solutions and print it out
        ++n_solutions;
        print_solution(board, size);
      }
      else
      {
        // Not in the last level, try to place queens in the 
        // next one using the current board
        n_solutions += place_queen(column+1, board, size);
      }
    }
  }

  return n_solutions;
}

// Solve the NQueens problem for <size>
int n_queens(int size)
{
  int* board = (int*) calloc(size, sizeof(int));
  if (board == NULL)
    abort();

  int n_solutions = place_queen(0, board, size);

  free(board);
  return n_solutions;
}


int main(int argc, char* argv[])
{
  int n = DEFAULT_SIZE;

  if (argc == 2)
    n = atoi(argv[1]);
  if (n < 2)
  {
    printf("You have specified N=%d, or an invalid N", n);
    abort();
  }

  time_t now = time(NULL);
  int n_solutions = n_queens(n);
  time_t done = time(NULL);

  printf("\n");
  printf("Queens %2d: total solutions: %d\n", n, n_solutions);
  printf("It took %ld sec\n", (long)(done-now));

  return 0;
}
