
/*
 * helloworld.cpp - Hello World Parallel Version
 * (c) Paulo Marques, pmarques@dei.uc.pt
 * April 03, 2003
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "mpi.h"

#define BUF_SIZE            80

int main(int argc, char* argv[])
{  
  int  id;                  // The rank of this process
  int  n_processes;         // The size of the world
  char buffer[BUF_SIZE];    // A message buffer

  // Init MPI
  MPI_Init(&argc, &argv);

  // Set the size of the world
  MPI_Comm_rank(MPI_COMM_WORLD, &id);
  MPI_Comm_size(MPI_COMM_WORLD, &n_processes);

  if (id == 0)
  {
    // Process 0 - the master
    // Receive a message from all other processes
    for (int i=1; i<=n_processes-1; i++)
    {
      MPI_Recv(buffer, BUF_SIZE, MPI_CHAR, MPI_ANY_SOURCE, MPI_ANY_TAG, 
               MPI_COMM_WORLD, MPI_STATUS_IGNORE);
      printf("%s", buffer);
    }
  }
  else
  {
    // All other processes send a message to process 0
    sprintf(buffer, "Hello, I'm process %d\n", id);
    MPI_Send(buffer, strlen(buffer)+1, MPI_CHAR, 0, 0, MPI_COMM_WORLD);
  }


  // All done
  MPI_Finalize();

  return 0;
}
