package com.trcinc.finance;

import java.rmi.RemoteException;
import javax.ejb.EJBException;
import javax.ejb.SessionBean;
import javax.ejb.SessionContext;

import com.trcinc.common.FinanceAppException;


/**
 * 
 * Stateless session bean that implements the FinanceService.
 * Uses XDoclet ejb tags to generate ejb artifacts.
 * 
 * @ejb.bean
 *    name="FinanceService"
 *    jndi-name="finance.FinanceService"
 *    local-jndi-name="finance.LocalFinanceService" 
 *    type="Stateless"
 * 
 */
public class FinanceServiceBean implements SessionBean
{

	/**
	 * The context of the stateful session bean.
	 */
	private SessionContext context;

	/**
	 * Constructor.
	 */
	public FinanceServiceBean()
	{
		super();
	}

	/**
	 * @ejb.create-method
	 */
	public void ejbCreate()
	{
		// would create an implementation class and hold its instance.
	}


	/**
	 * @ejb.interface-method view-type="both"
	 * 
	 */
	public void addStockQuote(String ticker, double price)
		throws InvalidTickerException, FinanceAppException
	{
		System.out.println ("***** addStockQuote for ticker (" + ticker + ")");
		getFinancePersistence ().addStockQuote(ticker, price);
	}

	/**
	 * @ejb.interface-method view-type="both"
	 * 
	 */
	public double getStockQuote(String ticker)
		throws InvalidTickerException, FinanceAppException
	{
		System.out.println ("***** GetStockQuote for ticker (" + ticker + ")");
		return getFinancePersistence ().getStockQuote(ticker);
	}

	/**
	 * Set the context for the session bean.
	 */
	public void setSessionContext(SessionContext context)
	{
		// Save in case we need something from the container later on.
		this.context = context;
	}

	/**
	 * Resume after passivate, which is effectively a suspend.
	 */
	public void ejbActivate()
	{
		// Force lazy initialization.
	}

	/**
	 * Suspend or deactivate.
	 */
	public void ejbPassivate()
	{
	}

	/**
	 * Destroy and release resources.
	 */
	public void ejbRemove()
	{
		// No resources to release.
	}
	
	private FinancePersistence getFinancePersistence ()
	{
		return new DefaultPersistence ();
	}
}
