package com.trcinc.finance;

import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.rmi.PortableRemoteObject;

import com.trcinc.common.FinanceAppException;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * Tests the FinanceSerivce EJB business methods.
 * 
 */
public class FinanceServiceTest extends TestCase
{

	private FinanceServiceRemote 	financeService;
	private String				  	stockTicker = "QQQ";
	private double				stockPrice = 25.0;

	/**
	 * Constructor for FinanceServiceTest.
	 * 
	 * @param name The name of this test instance.
	 */
	public FinanceServiceTest(String name)
	{
		super(name);
	}

	/**
	 * Lookup home interface and use it to create remote interface handle that
	 * will be used for testing.
	*/
	protected void setUp()
	{
		try
		{
			
			System.out.println ("setup test case for each test methods...");
			InitialContext jndiContext = new InitialContext();
			Object ref = jndiContext.lookup(FinanceServiceHome.JNDI_NAME);
			FinanceServiceHome financeServiceHome =
				(FinanceServiceHome) PortableRemoteObject.narrow(
					ref,
					FinanceServiceHome.class);
			financeService = financeServiceHome.create();
		}
		catch (NamingException e)
		{
			e.printStackTrace();
			fail("Could not locate EJB using JNDI: " + e.getMessage());
		}
		catch (RemoteException e)
		{
			e.printStackTrace();
			fail(
				"Could not communicate with EJB home interface: "
					+ e.getMessage());
		}
		catch (CreateException e)
		{
			e.printStackTrace();
			fail(
				"Could not create EJB using home interface: "
					+ e.getMessage());
		}
	}

	/**
	 * Setup the test suite (group of all tests) for the unit test.
	 */
	public static Test suite()
	{
		return new TestSuite(FinanceServiceTest.class);
	}


	/**
	 * Test getStockQuote for a single ticker.
	 */
	public void testGetStockQuote()
	{
		try
		{
			double returnedStockprice = financeService.getStockQuote(stockTicker);
			
			System.out.println ("Returned price=" + returnedStockprice);
			assertEquals("Stock price", stockPrice, returnedStockprice, 0.001);
		}
		catch (Exception e)
		{
			e.printStackTrace();
			fail("testGetStockQuote: "	+ e.getMessage());
		}

	}

	/**
	 * Run the unit tests in command line.
	 */
	public static void main(String[] args)
	{
		junit.textui.TestRunner.run(FinanceServiceTest.class);
	}
}
