package com.trcinc.finance.ws;

import java.net.URL;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.apache.axis.client.Service;

import com.trcinc.security.SecureSession;
import com.trcinc.security.ws.SecurityServiceSoapBindingStub;

/**
 * Tests the Finance web serivce methods.
 * 
 */
public class FinanceServiceWebServiceTest extends TestCase
{
	private String				  	stockTicker = "QQQ";
	private double				expectedStockPrice = 25.0;

	/**
	 * SOAP client proxy for the finance service client.
	 */
	private FinanceServiceSoapBindingStub financeService;

	/**
	 * SOAP client proxy for the security service client.
	 */
	private SecurityServiceSoapBindingStub securityService;

	/**
	 * The service object used to create calls to invoke web services.
	 */
	private Service webService;
	
	/**
	 * SecureSession returned by login to security service.
	 */
	
	private SecureSession secureSession; 

	/**
	 * Constructor for FinanceServiceWebServiceTest.
	 * 
	 * @param name The name of this test instance.
	 */
	public FinanceServiceWebServiceTest(String name) throws java.lang.Exception
	{
		super(name);
	}

	/**
	 * Setup before each test to make sure we run from a consistent state. 
	 */
	protected void setUp() throws java.lang.Exception
	{
		
		String host    = System.getProperty("webServiceHost", "localhost");
		String portStr = System.getProperty("webServicePort", "8080");
		String context = System.getProperty("webServiceContext", "axis/services");
		
		int port = Integer.parseInt(portStr);
		
		

		URL securityServiceEndPoint =
			new URL(
				"http://"
					+ host
					+ ":"
					+ port
					+ "/" 
					+ context
					+ "/SecurityService");
					
		URL financeServiceEndPoint =
			new URL(
				"http://"
					+ host
					+ ":"
					+ port
					+ "/" 
					+ context
					+ "/FinanceService");
					
					
							
		webService = new Service();
		webService.setMaintainSession(true);
		financeService =
			new FinanceServiceSoapBindingStub(
				financeServiceEndPoint,
				webService);
		securityService =
			new SecurityServiceSoapBindingStub(
				securityServiceEndPoint,
				webService);
				
		assertNotNull(financeService);			
		assertNotNull(securityService);			
	}

	/**
	 * Setup the test suite (group of all tests) for the unit test.
	 */
	public static Test suite()
	{
		return new TestSuite(FinanceServiceWebServiceTest.class);
	}
	
	
	/**
	 * Test login.
	 * 
	 * @throws Exception
	 */	
	public void testLogin () throws Exception
	{
		System.out.println ("*** testLogin ()");
		secureSession = securityService.login("testuser", "password");
	}
	
	/**
	 * Test get stock quote.
	 * 
	 * @throws Exception
	 */
	public void testGetStockQuote() throws Exception
	{
		System.out.println ("*** testGetStockQuote ()");
		double returnedStockprice = financeService.getStockQuote(stockTicker);
		
		System.out.println ("Returned price=" + returnedStockprice);
		assertEquals("Stock price", expectedStockPrice, returnedStockprice, 0.001);

	}

	/**
	 * Test log out.
	 * 
	 * @throws Exception
	 */
	public void testLogout () throws Exception
	{
		System.out.println ("*** testLogout ()");
		secureSession = securityService.login("testuser", "password");
		securityService.logout(secureSession);
	}
	

	/**
	 * Run the unit test in command line text mode.
	 */
	public static void main(String[] args)
	{
		junit.textui.TestRunner.run(FinanceServiceWebServiceTest.class);
	}
}
