package com.trcinc.security;

import java.rmi.RemoteException;
import javax.ejb.EJBException;
import javax.ejb.SessionBean;
import javax.ejb.SessionContext;

/**
 * Stateful session bean that implements the security service methods.
 * 
 * @ejb.bean
 *    name="SecurityService"
 *    jndi-name="finance.SecurityService"
 *    local-jndi-name="finance.LocalSecurityService" 
 *    type="Stateful"
 */
public class SecurityServiceBean implements SessionBean
{

	/**
	 * The context of the stateful session bean.
	 */
	private SessionContext context;

	/**
	 * Constructor.
	 */
	public SecurityServiceBean()
	{
		super();
	}

	/**
	 * @ejb.create-method
	 */
	public void ejbCreate()
	{
		// would create an implementation class and hold its instance.
	}

	/**
	 * Performs login authentication.
	 * 
	 * In this simple implementation login is permitted to any username.
	 * 
	 * @ejb.interface-method view-type="both"
	 * @ejb.webservice-method
	 * 		security-check="false"
	 */
	public SecureSession login(String username, String password)
		throws InvalidLoginException
	{
		String sessionId = createSessionId();
		
		SecureSession secureSession =
			new SecureSession(username, sessionId);

		return secureSession;
	}

	/**
	 * Performs logout clean up.
	 * 
	 * @ejb.interface-method view-type="both"
	 * @ejb.webservice-method
	 */
	public void logout(SecureSession session)
	{
	}

	/**
	 * Set the context for the session bean.
	 */
	public void setSessionContext(SessionContext context)
	{
		// Save in case we need something from the container later on.
		this.context = context;
	}

	/**
	 * Resume after passivate, which is effectively a suspend.
	 */
	public void ejbActivate()
	{
		// Force lazy initialization.
	}

	/**
	 * Suspend or deactivate.
	 */
	public void ejbPassivate()
	{
	}

	/**
	 * Destroy and release resources.
	 */
	public void ejbRemove()
	{
		// No resources to release.
	}
	
	/**
	 * Rerutns the session id.
	 * This simple implementation uses the system milli for session id.
	 * 
	 * @return String
	 */
	synchronized private String createSessionId()
	{
		String id =	String.valueOf(System.currentTimeMillis()) ;
		return id;
	}
}
