package com.trcinc.security.ws;

import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.ejb.EJBHome;
import javax.ejb.EJBLocalHome;
import javax.ejb.EJBLocalObject;
import javax.ejb.EJBObject;

import org.apache.axis.MessageContext;

import com.trcinc.common.AbstractWebService;
import com.trcinc.security.SecureSession;
import com.trcinc.security.SecurityServiceHome;
import com.trcinc.security.SecurityServiceLocal;
import com.trcinc.security.SecurityServiceLocalHome;

/**
 * This class implements the security service methods exposed as web service.
 * 
 * Note: Implementation for this service is little bit different than other
 * business services.
 * 
 */

public class SecurityServiceSoapBindingImpl extends AbstractWebService
{
	/**
	 * Cache key to store the EJB local object on the SOAP session.
	 */
	public static final String SESSION_EJB_LOCAL_OBJ_NAME =
		"com.trcinc.security.SecurityServiceSoapBindingImpl.ejbLocalRef";

	/**
	 * Constructor for FinanceServiceSoapBindingImpl.
	 */
	public SecurityServiceSoapBindingImpl()
	{
	}


	/**
	 * Creates the SecurityService EJB local object from the
	 * local home interface.
	 * 
	 * @see com.trcinc.common.AbstractWebService#createLocalEjb(EJBLocalHome)
	 */
	public EJBLocalObject createLocalEjb(EJBLocalHome home)
		throws CreateException
	{
		return ((SecurityServiceLocalHome) home).create();
	}

	/**
	 * Returns the SecurityService local interface.
	 * 
	 * Uses the base class helper method to create the class.
	 * 
	 * @return FinanceServiceLocal
	 * @throws Exception
	 */
	public SecurityServiceLocal getLocalService() throws Exception
	{
		SecurityServiceLocal service = null;
		try
		{
			service =
				(SecurityServiceLocal) getLocalService(SecurityServiceLocalHome
					.JNDI_NAME,
					SecurityServiceLocalHome.class,
					SESSION_EJB_LOCAL_OBJ_NAME);
		}
		catch (Exception e)
		{
			e.printStackTrace();
			throw e;
		}
		return service;
	}
	
	/**
	 * Returns the name of the service this soap binding implementation.
	 * 
	 * @return String
	 */
	public String getServiceName()
	{
		return "SecurityService";
	}
	
	/**
	 * Logs in the user and stores the SecureSession in SOAP session for
	 * future verification.
	 * 
	 * @param username
	 * @param password
	 * @return SecureSession
	 * @throws Exception
	 */

	public SecureSession login(String username, String password)
		throws Exception
	{
		String _methodName_ = "login";

		System.out.println("** " + _methodName_);

		SecureSession secureSession =
			getLocalService().login(username, password);

		//
		// Register the session with SOAP for future security check.
		//
		registerSecureSession(secureSession);

		return secureSession;
	}

	/**
	 * Logs out the user and removes the SecureSession from SOAP session.
	 * 
	 * @param session
	 * @throws Exception
	 */
	public void logout(SecureSession session) throws Exception
	{

		String _methodName_ = "logout";

		System.out.println("** " + _methodName_);

		authorizeMethodAccess(getServiceName(), _methodName_);

		getLocalService().logout(session);

		//
		// Remove the the session, so security check will fail.
		//
		unRegisterSecureSession();
	}

	/**
	 * Adds the SecureSession to SOAP session.
	 * 
	 * @param secureSession
	 */

	private void registerSecureSession(SecureSession secureSession)
	{
		MessageContext messageContext = MessageContext.getCurrentContext();
		messageContext.setMaintainSession(true);
		getSession().set(SESSION_KEY_SECURE_SESSION, secureSession);
	}

	/**
	 * Removes the SecureSession from SOAP session.
	 * 
	 */
	private void unRegisterSecureSession()
	{
		getSession().remove(SESSION_KEY_SECURE_SESSION);
	}

}
