package com.trcinc.security.ws;

import java.net.URL;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.apache.axis.AxisFault;
import org.apache.axis.client.Service;

import com.trcinc.security.SecureSession;
import com.trcinc.security.ws.SecurityServiceSoapBindingStub;

/**
 * Tests the Finance web serivce methods.
 *
 */
public class SecurityServiceWebServiceTest extends TestCase
{

	/**
	 * SOAP client proxy for the security service client.
	 */
	private SecurityServiceSoapBindingStub securityService;

	/**
	 * The service object used to create calls to invoke web services.
	 */
	private Service webService;
	
	/**
	 * Secure session returned by the security service on login.
	 */
	
	private SecureSession secureSession; 

	/**
	 * Constructor for SecurityServiceWebServiceTest.
	 * 
	 * @param name The name of this test instance.
	 */
	public SecurityServiceWebServiceTest(String name) throws java.lang.Exception
	{
		super(name);

	}

	/**
	 * Setup before each test to make sure we run from a consistent state. 
	 */
	protected void setUp() throws java.lang.Exception
	{
		
		String host    = System.getProperty("webServiceHost", "localhost");
		String portStr = System.getProperty("webServicePort", "8080");
		String context = System.getProperty("webServiceContext", "axis");
		
		int port = Integer.parseInt(portStr);
		
		

		URL securityServiceEndPoint =
			new URL(
				"http://"
					+ host
					+ ":"
					+ port
					+ "/" 
					+ context
					+ "/SecurityService");
					
							
		webService = new Service();
		webService.setMaintainSession(true);
		securityService =
			new SecurityServiceSoapBindingStub(
				securityServiceEndPoint,
				webService);
				
		assertNotNull(securityService);			
	}

	/**
	 * Setup the test suite (group of all tests) for the unit test.
	 */
	public static Test suite()
	{
		return new TestSuite(SecurityServiceWebServiceTest.class);
	}
	
	
	
	public void testLoginLogout () throws Exception
	{
		System.out.println ("*** testLogin ()");
		secureSession = securityService.login("testuser", "password");
		assertNotNull(secureSession);			
		System.out.println ("*** testLogout ()");
		securityService.logout(secureSession);
	}
	


	/**
	 * Run the unit test in command line text mode.
	 */
	public static void main(String[] args)
	{
		junit.textui.TestRunner.run(SecurityServiceWebServiceTest.class);
	}
}
